# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_wwtp_data_bus_service.api_client import ApiClient
from dhicn_wwtp_data_bus_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class IntelligentMccrApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v2_intelligent_mccr_add_rates_get(self, **kwargs):  # noqa: E501
        """获取铁催化剂加药，或者双氧水加药的实际投加速率与计算投加速率 Get actual and calculated dosing rate data of iron catalysts or hydrogen peroxide  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_add_rates_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param int category: 药剂类型 dosage type
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CdAdditionRateOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_add_rates_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_add_rates_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取铁催化剂加药，或者双氧水加药的实际投加速率与计算投加速率 Get actual and calculated dosing rate data of iron catalysts or hydrogen peroxide  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_add_rates_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param int category: 药剂类型 dosage type
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CdAdditionRateOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'category',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_add_rates_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'category' in local_var_params and local_var_params['category'] is not None:  # noqa: E501
            query_params.append(('category', local_var_params['category']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/add-rates', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CdAdditionRateOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_calculate_mccr_dosage_post(self, **kwargs):  # noqa: E501
        """计算指定产线的MCCR加药量 calculate MCCR's dosage by product line  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_calculate_mccr_dosage_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[DosingParamSettingDto] dosing_param_setting_dto:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_calculate_mccr_dosage_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_calculate_mccr_dosage_post_with_http_info(self, **kwargs):  # noqa: E501
        """计算指定产线的MCCR加药量 calculate MCCR's dosage by product line  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_calculate_mccr_dosage_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[DosingParamSettingDto] dosing_param_setting_dto:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'dosing_param_setting_dto'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_calculate_mccr_dosage_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'dosing_param_setting_dto' in local_var_params:
            body_params = local_var_params['dosing_param_setting_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/calculate-mccr-dosage', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_catalysis_before_after_get(self, **kwargs):  # noqa: E501
        """获取催化反应前后的浊度、电导 Get online turbidity and conductivity data before and after catalysis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_catalysis_before_after_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_line:
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CatalysisBfOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_catalysis_before_after_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_catalysis_before_after_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取催化反应前后的浊度、电导 Get online turbidity and conductivity data before and after catalysis  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_catalysis_before_after_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_line:
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CatalysisBfOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'product_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_catalysis_before_after_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'product_line' in local_var_params and local_var_params['product_line'] is not None:  # noqa: E501
            query_params.append(('productLine', local_var_params['product_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/catalysis-before-after', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CatalysisBfOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_catalysis_tank_data_get(self, **kwargs):  # noqa: E501
        """获取催化池的进水量、pH、ORP数据 Get online inflow, pH, ORP data in the catalysis pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_catalysis_tank_data_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_line:
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CatalysisTankOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_catalysis_tank_data_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_catalysis_tank_data_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取催化池的进水量、pH、ORP数据 Get online inflow, pH, ORP data in the catalysis pool  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_catalysis_tank_data_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str product_line:
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CatalysisTankOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'product_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_catalysis_tank_data_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'product_line' in local_var_params and local_var_params['product_line'] is not None:  # noqa: E501
            query_params.append(('productLine', local_var_params['product_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/catalysis-tank-data', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CatalysisTankOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_daily_statistics_export_get(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计文件导出 Export dosing daily statistic results of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_daily_statistics_export_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_daily_statistics_export_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_daily_statistics_export_get_with_http_info(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计文件导出 Export dosing daily statistic results of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_daily_statistics_export_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_daily_statistics_export_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/daily-statistics/export', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_daily_statistics_get(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计查询 Get dosing daily statistic results of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_daily_statistics_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[DosingStatisticDailysOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_daily_statistics_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_daily_statistics_get_with_http_info(self, **kwargs):  # noqa: E501
        """指定时间段内加药统计查询 Get dosing daily statistic results of a certain period  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_daily_statistics_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[DosingStatisticDailysOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_daily_statistics_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/daily-statistics', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[DosingStatisticDailysOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_dosing_log_export_get(self, **kwargs):  # noqa: E501
        """指定时间段内加药报表文件导出 Export dosing logs of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_dosing_log_export_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_dosing_log_export_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_dosing_log_export_get_with_http_info(self, **kwargs):  # noqa: E501
        """指定时间段内加药报表文件导出 Export dosing logs of a certain period as an excel file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_dosing_log_export_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str production_line: 工艺线代码 product line code
        :param str start_time: 开始时间 start time
        :param str end_time: 结束时间 end time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'production_line',
            'start_time',
            'end_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_dosing_log_export_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'production_line' in local_var_params and local_var_params['production_line'] is not None:  # noqa: E501
            query_params.append(('productionLine', local_var_params['production_line']))  # noqa: E501
        if 'start_time' in local_var_params and local_var_params['start_time'] is not None:  # noqa: E501
            query_params.append(('startTime', local_var_params['start_time']))  # noqa: E501
        if 'end_time' in local_var_params and local_var_params['end_time'] is not None:  # noqa: E501
            query_params.append(('endTime', local_var_params['end_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/dosing-log/export', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_plc_control_by_product_line_post(self, **kwargs):  # noqa: E501
        """执行指定产线的MCCR加药plc控制，同时写入加药日志 Execute MCCR dosing plc control and write dosing logs for one product line  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_plc_control_by_product_line_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ExecutePlcInput execute_plc_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_plc_control_by_product_line_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_plc_control_by_product_line_post_with_http_info(self, **kwargs):  # noqa: E501
        """执行指定产线的MCCR加药plc控制，同时写入加药日志 Execute MCCR dosing plc control and write dosing logs for one product line  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_plc_control_by_product_line_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ExecutePlcInput execute_plc_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'execute_plc_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_plc_control_by_product_line_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'execute_plc_input' in local_var_params:
            body_params = local_var_params['execute_plc_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/plc-control-by-product-line', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_intelligent_mccr_plc_control_get(self, **kwargs):  # noqa: E501
        """执行MCCR加药plc控制，同时写入加药日志 Execute MCCR dosing plc control and write dosing logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_plc_control_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str current_time: 当前时刻 current time
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_intelligent_mccr_plc_control_get_with_http_info(**kwargs)  # noqa: E501

    def api_v2_intelligent_mccr_plc_control_get_with_http_info(self, **kwargs):  # noqa: E501
        """执行MCCR加药plc控制，同时写入加药日志 Execute MCCR dosing plc control and write dosing logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_intelligent_mccr_plc_control_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str current_time: 当前时刻 current time
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'current_time'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_intelligent_mccr_plc_control_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'current_time' in local_var_params and local_var_params['current_time'] is not None:  # noqa: E501
            query_params.append(('currentTime', local_var_params['current_time']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/intelligent-mccr/plc-control', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class AlarmLogDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'alarm_data_type': 'str',
        'alarm_policy': 'int',
        'alarm_time': 'datetime',
        'x': 'float',
        'y': 'float',
        'z': 'float',
        'model_id': 'str',
        'model_value': 'float',
        'device_name': 'str',
        'indicator_name': 'str',
        'measure_value': 'float',
        'value_diff': 'float'
    }

    attribute_map = {
        'alarm_data_type': 'alarmDataType',
        'alarm_policy': 'alarmPolicy',
        'alarm_time': 'alarmTime',
        'x': 'x',
        'y': 'y',
        'z': 'z',
        'model_id': 'modelId',
        'model_value': 'modelValue',
        'device_name': 'deviceName',
        'indicator_name': 'indicatorName',
        'measure_value': 'measureValue',
        'value_diff': 'valueDiff'
    }

    def __init__(self, alarm_data_type=None, alarm_policy=None, alarm_time=None, x=None, y=None, z=None, model_id=None, model_value=None, device_name=None, indicator_name=None, measure_value=None, value_diff=None, local_vars_configuration=None):  # noqa: E501
        """AlarmLogDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._alarm_data_type = None
        self._alarm_policy = None
        self._alarm_time = None
        self._x = None
        self._y = None
        self._z = None
        self._model_id = None
        self._model_value = None
        self._device_name = None
        self._indicator_name = None
        self._measure_value = None
        self._value_diff = None
        self.discriminator = None

        self.alarm_data_type = alarm_data_type
        if alarm_policy is not None:
            self.alarm_policy = alarm_policy
        if alarm_time is not None:
            self.alarm_time = alarm_time
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if z is not None:
            self.z = z
        self.model_id = model_id
        if model_value is not None:
            self.model_value = model_value
        self.device_name = device_name
        self.indicator_name = indicator_name
        if measure_value is not None:
            self.measure_value = measure_value
        if value_diff is not None:
            self.value_diff = value_diff

    @property
    def alarm_data_type(self):
        """Gets the alarm_data_type of this AlarmLogDto.  # noqa: E501

        报警数据类型(Pressure、Flow...)  # noqa: E501

        :return: The alarm_data_type of this AlarmLogDto.  # noqa: E501
        :rtype: str
        """
        return self._alarm_data_type

    @alarm_data_type.setter
    def alarm_data_type(self, alarm_data_type):
        """Sets the alarm_data_type of this AlarmLogDto.

        报警数据类型(Pressure、Flow...)  # noqa: E501

        :param alarm_data_type: The alarm_data_type of this AlarmLogDto.  # noqa: E501
        :type: str
        """

        self._alarm_data_type = alarm_data_type

    @property
    def alarm_policy(self):
        """Gets the alarm_policy of this AlarmLogDto.  # noqa: E501

        报警策略（0：阈值报警，1：范围值报警）  # noqa: E501

        :return: The alarm_policy of this AlarmLogDto.  # noqa: E501
        :rtype: int
        """
        return self._alarm_policy

    @alarm_policy.setter
    def alarm_policy(self, alarm_policy):
        """Sets the alarm_policy of this AlarmLogDto.

        报警策略（0：阈值报警，1：范围值报警）  # noqa: E501

        :param alarm_policy: The alarm_policy of this AlarmLogDto.  # noqa: E501
        :type: int
        """

        self._alarm_policy = alarm_policy

    @property
    def alarm_time(self):
        """Gets the alarm_time of this AlarmLogDto.  # noqa: E501

        报警时间  # noqa: E501

        :return: The alarm_time of this AlarmLogDto.  # noqa: E501
        :rtype: datetime
        """
        return self._alarm_time

    @alarm_time.setter
    def alarm_time(self, alarm_time):
        """Sets the alarm_time of this AlarmLogDto.

        报警时间  # noqa: E501

        :param alarm_time: The alarm_time of this AlarmLogDto.  # noqa: E501
        :type: datetime
        """

        self._alarm_time = alarm_time

    @property
    def x(self):
        """Gets the x of this AlarmLogDto.  # noqa: E501


        :return: The x of this AlarmLogDto.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this AlarmLogDto.


        :param x: The x of this AlarmLogDto.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this AlarmLogDto.  # noqa: E501


        :return: The y of this AlarmLogDto.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this AlarmLogDto.


        :param y: The y of this AlarmLogDto.  # noqa: E501
        :type: float
        """

        self._y = y

    @property
    def z(self):
        """Gets the z of this AlarmLogDto.  # noqa: E501


        :return: The z of this AlarmLogDto.  # noqa: E501
        :rtype: float
        """
        return self._z

    @z.setter
    def z(self, z):
        """Sets the z of this AlarmLogDto.


        :param z: The z of this AlarmLogDto.  # noqa: E501
        :type: float
        """

        self._z = z

    @property
    def model_id(self):
        """Gets the model_id of this AlarmLogDto.  # noqa: E501

        模型点位id  # noqa: E501

        :return: The model_id of this AlarmLogDto.  # noqa: E501
        :rtype: str
        """
        return self._model_id

    @model_id.setter
    def model_id(self, model_id):
        """Sets the model_id of this AlarmLogDto.

        模型点位id  # noqa: E501

        :param model_id: The model_id of this AlarmLogDto.  # noqa: E501
        :type: str
        """

        self._model_id = model_id

    @property
    def model_value(self):
        """Gets the model_value of this AlarmLogDto.  # noqa: E501

        模型结果值  # noqa: E501

        :return: The model_value of this AlarmLogDto.  # noqa: E501
        :rtype: float
        """
        return self._model_value

    @model_value.setter
    def model_value(self, model_value):
        """Sets the model_value of this AlarmLogDto.

        模型结果值  # noqa: E501

        :param model_value: The model_value of this AlarmLogDto.  # noqa: E501
        :type: float
        """

        self._model_value = model_value

    @property
    def device_name(self):
        """Gets the device_name of this AlarmLogDto.  # noqa: E501

        设备名称  # noqa: E501

        :return: The device_name of this AlarmLogDto.  # noqa: E501
        :rtype: str
        """
        return self._device_name

    @device_name.setter
    def device_name(self, device_name):
        """Sets the device_name of this AlarmLogDto.

        设备名称  # noqa: E501

        :param device_name: The device_name of this AlarmLogDto.  # noqa: E501
        :type: str
        """

        self._device_name = device_name

    @property
    def indicator_name(self):
        """Gets the indicator_name of this AlarmLogDto.  # noqa: E501

        指标名称  # noqa: E501

        :return: The indicator_name of this AlarmLogDto.  # noqa: E501
        :rtype: str
        """
        return self._indicator_name

    @indicator_name.setter
    def indicator_name(self, indicator_name):
        """Sets the indicator_name of this AlarmLogDto.

        指标名称  # noqa: E501

        :param indicator_name: The indicator_name of this AlarmLogDto.  # noqa: E501
        :type: str
        """

        self._indicator_name = indicator_name

    @property
    def measure_value(self):
        """Gets the measure_value of this AlarmLogDto.  # noqa: E501

        实测值  # noqa: E501

        :return: The measure_value of this AlarmLogDto.  # noqa: E501
        :rtype: float
        """
        return self._measure_value

    @measure_value.setter
    def measure_value(self, measure_value):
        """Sets the measure_value of this AlarmLogDto.

        实测值  # noqa: E501

        :param measure_value: The measure_value of this AlarmLogDto.  # noqa: E501
        :type: float
        """

        self._measure_value = measure_value

    @property
    def value_diff(self):
        """Gets the value_diff of this AlarmLogDto.  # noqa: E501

        差值  # noqa: E501

        :return: The value_diff of this AlarmLogDto.  # noqa: E501
        :rtype: float
        """
        return self._value_diff

    @value_diff.setter
    def value_diff(self, value_diff):
        """Sets the value_diff of this AlarmLogDto.

        差值  # noqa: E501

        :param value_diff: The value_diff of this AlarmLogDto.  # noqa: E501
        :type: float
        """

        self._value_diff = value_diff

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AlarmLogDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AlarmLogDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class RealTimeData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'name': 'str',
        'latest_value': 'float',
        'description': 'str',
        'ts_datas': 'list[TsData]'
    }

    attribute_map = {
        'code': 'code',
        'name': 'name',
        'latest_value': 'latestValue',
        'description': 'description',
        'ts_datas': 'tsDatas'
    }

    def __init__(self, code=None, name=None, latest_value=None, description=None, ts_datas=None, local_vars_configuration=None):  # noqa: E501
        """RealTimeData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._name = None
        self._latest_value = None
        self._description = None
        self._ts_datas = None
        self.discriminator = None

        self.code = code
        self.name = name
        if latest_value is not None:
            self.latest_value = latest_value
        self.description = description
        self.ts_datas = ts_datas

    @property
    def code(self):
        """Gets the code of this RealTimeData.  # noqa: E501

        毒性指标 toxicity indicator  # noqa: E501

        :return: The code of this RealTimeData.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this RealTimeData.

        毒性指标 toxicity indicator  # noqa: E501

        :param code: The code of this RealTimeData.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def name(self):
        """Gets the name of this RealTimeData.  # noqa: E501

        指标名称 indicator name  # noqa: E501

        :return: The name of this RealTimeData.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RealTimeData.

        指标名称 indicator name  # noqa: E501

        :param name: The name of this RealTimeData.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def latest_value(self):
        """Gets the latest_value of this RealTimeData.  # noqa: E501

        最新值 latest value  # noqa: E501

        :return: The latest_value of this RealTimeData.  # noqa: E501
        :rtype: float
        """
        return self._latest_value

    @latest_value.setter
    def latest_value(self, latest_value):
        """Sets the latest_value of this RealTimeData.

        最新值 latest value  # noqa: E501

        :param latest_value: The latest_value of this RealTimeData.  # noqa: E501
        :type: float
        """

        self._latest_value = latest_value

    @property
    def description(self):
        """Gets the description of this RealTimeData.  # noqa: E501

        毒性描述 toxicity description  # noqa: E501

        :return: The description of this RealTimeData.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RealTimeData.

        毒性描述 toxicity description  # noqa: E501

        :param description: The description of this RealTimeData.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def ts_datas(self):
        """Gets the ts_datas of this RealTimeData.  # noqa: E501

        时间序列数据 time-series data  # noqa: E501

        :return: The ts_datas of this RealTimeData.  # noqa: E501
        :rtype: list[TsData]
        """
        return self._ts_datas

    @ts_datas.setter
    def ts_datas(self, ts_datas):
        """Sets the ts_datas of this RealTimeData.

        时间序列数据 time-series data  # noqa: E501

        :param ts_datas: The ts_datas of this RealTimeData.  # noqa: E501
        :type: list[TsData]
        """

        self._ts_datas = ts_datas

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RealTimeData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RealTimeData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class StatisticSettingOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'template_id': 'str',
        'result_type': 'str',
        'show_name': 'str',
        'code': 'str',
        'data_type': 'str',
        'unit': 'str',
        'model_ids': 'str',
        'sort': 'int',
        'is_show_in_chart': 'bool',
        'scenario_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'template_id': 'templateId',
        'result_type': 'resultType',
        'show_name': 'showName',
        'code': 'code',
        'data_type': 'dataType',
        'unit': 'unit',
        'model_ids': 'modelIds',
        'sort': 'sort',
        'is_show_in_chart': 'isShowInChart',
        'scenario_type': 'scenarioType'
    }

    def __init__(self, id=None, template_id=None, result_type=None, show_name=None, code=None, data_type=None, unit=None, model_ids=None, sort=None, is_show_in_chart=None, scenario_type=None, local_vars_configuration=None):  # noqa: E501
        """StatisticSettingOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._template_id = None
        self._result_type = None
        self._show_name = None
        self._code = None
        self._data_type = None
        self._unit = None
        self._model_ids = None
        self._sort = None
        self._is_show_in_chart = None
        self._scenario_type = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if template_id is not None:
            self.template_id = template_id
        self.result_type = result_type
        self.show_name = show_name
        self.code = code
        self.data_type = data_type
        self.unit = unit
        self.model_ids = model_ids
        if sort is not None:
            self.sort = sort
        if is_show_in_chart is not None:
            self.is_show_in_chart = is_show_in_chart
        self.scenario_type = scenario_type

    @property
    def id(self):
        """Gets the id of this StatisticSettingOutput.  # noqa: E501


        :return: The id of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this StatisticSettingOutput.


        :param id: The id of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def template_id(self):
        """Gets the template_id of this StatisticSettingOutput.  # noqa: E501


        :return: The template_id of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this StatisticSettingOutput.


        :param template_id: The template_id of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def result_type(self):
        """Gets the result_type of this StatisticSettingOutput.  # noqa: E501

        结果类型，0-OrificeStatistic、1-PumpStatistic、2-LinkStatistic  # noqa: E501

        :return: The result_type of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._result_type

    @result_type.setter
    def result_type(self, result_type):
        """Sets the result_type of this StatisticSettingOutput.

        结果类型，0-OrificeStatistic、1-PumpStatistic、2-LinkStatistic  # noqa: E501

        :param result_type: The result_type of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._result_type = result_type

    @property
    def show_name(self):
        """Gets the show_name of this StatisticSettingOutput.  # noqa: E501


        :return: The show_name of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._show_name

    @show_name.setter
    def show_name(self, show_name):
        """Sets the show_name of this StatisticSettingOutput.


        :param show_name: The show_name of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._show_name = show_name

    @property
    def code(self):
        """Gets the code of this StatisticSettingOutput.  # noqa: E501


        :return: The code of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this StatisticSettingOutput.


        :param code: The code of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def data_type(self):
        """Gets the data_type of this StatisticSettingOutput.  # noqa: E501


        :return: The data_type of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this StatisticSettingOutput.


        :param data_type: The data_type of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._data_type = data_type

    @property
    def unit(self):
        """Gets the unit of this StatisticSettingOutput.  # noqa: E501


        :return: The unit of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this StatisticSettingOutput.


        :param unit: The unit of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def model_ids(self):
        """Gets the model_ids of this StatisticSettingOutput.  # noqa: E501


        :return: The model_ids of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_ids

    @model_ids.setter
    def model_ids(self, model_ids):
        """Sets the model_ids of this StatisticSettingOutput.


        :param model_ids: The model_ids of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._model_ids = model_ids

    @property
    def sort(self):
        """Gets the sort of this StatisticSettingOutput.  # noqa: E501


        :return: The sort of this StatisticSettingOutput.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this StatisticSettingOutput.


        :param sort: The sort of this StatisticSettingOutput.  # noqa: E501
        :type: int
        """

        self._sort = sort

    @property
    def is_show_in_chart(self):
        """Gets the is_show_in_chart of this StatisticSettingOutput.  # noqa: E501


        :return: The is_show_in_chart of this StatisticSettingOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_show_in_chart

    @is_show_in_chart.setter
    def is_show_in_chart(self, is_show_in_chart):
        """Sets the is_show_in_chart of this StatisticSettingOutput.


        :param is_show_in_chart: The is_show_in_chart of this StatisticSettingOutput.  # noqa: E501
        :type: bool
        """

        self._is_show_in_chart = is_show_in_chart

    @property
    def scenario_type(self):
        """Gets the scenario_type of this StatisticSettingOutput.  # noqa: E501


        :return: The scenario_type of this StatisticSettingOutput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_type

    @scenario_type.setter
    def scenario_type(self, scenario_type):
        """Sets the scenario_type of this StatisticSettingOutput.


        :param scenario_type: The scenario_type of this StatisticSettingOutput.  # noqa: E501
        :type: str
        """

        self._scenario_type = scenario_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatisticSettingOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, StatisticSettingOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-information-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_information_service.configuration import Configuration


class ScenarioInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'min_io_bucket': 'str',
        'min_io_path': 'str',
        'tenant_id': 'str',
        'version': 'str',
        'description': 'str',
        'state': 'str',
        'auto_amend': 'int',
        'online_first': 'int',
        'published': 'int',
        'calculated': 'int',
        'checked': 'int',
        'modified': 'int',
        'auto_calculate': 'int',
        'create_time': 'str',
        'end_time': 'str',
        'start_time': 'str',
        'current_time': 'str',
        'project_file': 'str',
        'relative_folder': 'str',
        'enabled': 'int',
        'read_only': 'int',
        'inherited_scenario': 'str',
        'id': 'str',
        'scenario_code': 'str',
        'scenario_name': 'str',
        'model_type': 'str',
        'model_sub_type': 'str',
        'template': 'int'
    }

    attribute_map = {
        'name': 'name',
        'min_io_bucket': 'minIOBucket',
        'min_io_path': 'minIOPath',
        'tenant_id': 'tenantId',
        'version': 'version',
        'description': 'description',
        'state': 'state',
        'auto_amend': 'autoAmend',
        'online_first': 'onlineFirst',
        'published': 'published',
        'calculated': 'calculated',
        'checked': '_checked',
        'modified': 'modified',
        'auto_calculate': 'autoCalculate',
        'create_time': 'createTime',
        'end_time': 'endTime',
        'start_time': 'startTime',
        'current_time': 'currentTime',
        'project_file': 'projectFile',
        'relative_folder': 'relativeFolder',
        'enabled': 'enabled',
        'read_only': 'readOnly',
        'inherited_scenario': 'inheritedScenario',
        'id': 'id',
        'scenario_code': 'scenarioCode',
        'scenario_name': 'scenarioName',
        'model_type': 'modelType',
        'model_sub_type': 'modelSubType',
        'template': 'template'
    }

    def __init__(self, name=None, min_io_bucket=None, min_io_path=None, tenant_id=None, version=None, description=None, state=None, auto_amend=None, online_first=None, published=None, calculated=None, checked=None, modified=None, auto_calculate=None, create_time=None, end_time=None, start_time=None, current_time=None, project_file=None, relative_folder=None, enabled=None, read_only=None, inherited_scenario=None, id=None, scenario_code=None, scenario_name=None, model_type=None, model_sub_type=None, template=None, local_vars_configuration=None):  # noqa: E501
        """ScenarioInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._min_io_bucket = None
        self._min_io_path = None
        self._tenant_id = None
        self._version = None
        self._description = None
        self._state = None
        self._auto_amend = None
        self._online_first = None
        self._published = None
        self._calculated = None
        self._checked = None
        self._modified = None
        self._auto_calculate = None
        self._create_time = None
        self._end_time = None
        self._start_time = None
        self._current_time = None
        self._project_file = None
        self._relative_folder = None
        self._enabled = None
        self._read_only = None
        self._inherited_scenario = None
        self._id = None
        self._scenario_code = None
        self._scenario_name = None
        self._model_type = None
        self._model_sub_type = None
        self._template = None
        self.discriminator = None

        self.name = name
        self.min_io_bucket = min_io_bucket
        self.min_io_path = min_io_path
        self.tenant_id = tenant_id
        self.version = version
        self.description = description
        self.state = state
        if auto_amend is not None:
            self.auto_amend = auto_amend
        if online_first is not None:
            self.online_first = online_first
        if published is not None:
            self.published = published
        if calculated is not None:
            self.calculated = calculated
        if checked is not None:
            self.checked = checked
        if modified is not None:
            self.modified = modified
        if auto_calculate is not None:
            self.auto_calculate = auto_calculate
        self.create_time = create_time
        self.end_time = end_time
        self.start_time = start_time
        self.current_time = current_time
        self.project_file = project_file
        self.relative_folder = relative_folder
        if enabled is not None:
            self.enabled = enabled
        if read_only is not None:
            self.read_only = read_only
        self.inherited_scenario = inherited_scenario
        self.id = id
        self.scenario_code = scenario_code
        self.scenario_name = scenario_name
        self.model_type = model_type
        self.model_sub_type = model_sub_type
        if template is not None:
            self.template = template

    @property
    def name(self):
        """Gets the name of this ScenarioInfo.  # noqa: E501

        名称 name  # noqa: E501

        :return: The name of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ScenarioInfo.

        名称 name  # noqa: E501

        :param name: The name of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def min_io_bucket(self):
        """Gets the min_io_bucket of this ScenarioInfo.  # noqa: E501

        在分布式文件系统上的存储桶 store bucket on distributed file system  # noqa: E501

        :return: The min_io_bucket of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._min_io_bucket

    @min_io_bucket.setter
    def min_io_bucket(self, min_io_bucket):
        """Sets the min_io_bucket of this ScenarioInfo.

        在分布式文件系统上的存储桶 store bucket on distributed file system  # noqa: E501

        :param min_io_bucket: The min_io_bucket of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._min_io_bucket = min_io_bucket

    @property
    def min_io_path(self):
        """Gets the min_io_path of this ScenarioInfo.  # noqa: E501

        在分布式文件系统上的存储路径 store path on distributed file system  # noqa: E501

        :return: The min_io_path of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._min_io_path

    @min_io_path.setter
    def min_io_path(self, min_io_path):
        """Sets the min_io_path of this ScenarioInfo.

        在分布式文件系统上的存储路径 store path on distributed file system  # noqa: E501

        :param min_io_path: The min_io_path of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._min_io_path = min_io_path

    @property
    def tenant_id(self):
        """Gets the tenant_id of this ScenarioInfo.  # noqa: E501

        租户ID tenant Id  # noqa: E501

        :return: The tenant_id of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this ScenarioInfo.

        租户ID tenant Id  # noqa: E501

        :param tenant_id: The tenant_id of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def version(self):
        """Gets the version of this ScenarioInfo.  # noqa: E501

        版本 version  # noqa: E501

        :return: The version of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ScenarioInfo.

        版本 version  # noqa: E501

        :param version: The version of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._version = version

    @property
    def description(self):
        """Gets the description of this ScenarioInfo.  # noqa: E501

        方案的描述 scenario description  # noqa: E501

        :return: The description of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ScenarioInfo.

        方案的描述 scenario description  # noqa: E501

        :param description: The description of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def state(self):
        """Gets the state of this ScenarioInfo.  # noqa: E501

        方案的状态 scenario's status  # noqa: E501

        :return: The state of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ScenarioInfo.

        方案的状态 scenario's status  # noqa: E501

        :param state: The state of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def auto_amend(self):
        """Gets the auto_amend of this ScenarioInfo.  # noqa: E501

        1表示进行自动修改，0表示不进行自动修正 1 for auto amend, 0 for not auto amend  # noqa: E501

        :return: The auto_amend of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._auto_amend

    @auto_amend.setter
    def auto_amend(self, auto_amend):
        """Sets the auto_amend of this ScenarioInfo.

        1表示进行自动修改，0表示不进行自动修正 1 for auto amend, 0 for not auto amend  # noqa: E501

        :param auto_amend: The auto_amend of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._auto_amend = auto_amend

    @property
    def online_first(self):
        """Gets the online_first of this ScenarioInfo.  # noqa: E501

        1表示优先使用在线数据，0表示非优先使用在线数据 1 for online first, 0 for not online first  # noqa: E501

        :return: The online_first of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._online_first

    @online_first.setter
    def online_first(self, online_first):
        """Sets the online_first of this ScenarioInfo.

        1表示优先使用在线数据，0表示非优先使用在线数据 1 for online first, 0 for not online first  # noqa: E501

        :param online_first: The online_first of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._online_first = online_first

    @property
    def published(self):
        """Gets the published of this ScenarioInfo.  # noqa: E501

        1表示已发布，0表示未发布 1 for published, 0 for not published  # noqa: E501

        :return: The published of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._published

    @published.setter
    def published(self, published):
        """Sets the published of this ScenarioInfo.

        1表示已发布，0表示未发布 1 for published, 0 for not published  # noqa: E501

        :param published: The published of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._published = published

    @property
    def calculated(self):
        """Gets the calculated of this ScenarioInfo.  # noqa: E501

        1表示计算完成，0表示未计算完成 1 for calculated, 0 for not calculated  # noqa: E501

        :return: The calculated of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._calculated

    @calculated.setter
    def calculated(self, calculated):
        """Sets the calculated of this ScenarioInfo.

        1表示计算完成，0表示未计算完成 1 for calculated, 0 for not calculated  # noqa: E501

        :param calculated: The calculated of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._calculated = calculated

    @property
    def checked(self):
        """Gets the checked of this ScenarioInfo.  # noqa: E501

        1表示被选中，0表示未被选中 1 for checked, 0 for unchecked  # noqa: E501

        :return: The checked of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._checked

    @checked.setter
    def checked(self, checked):
        """Sets the checked of this ScenarioInfo.

        1表示被选中，0表示未被选中 1 for checked, 0 for unchecked  # noqa: E501

        :param checked: The checked of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._checked = checked

    @property
    def modified(self):
        """Gets the modified of this ScenarioInfo.  # noqa: E501

        1表示修改过，0表示没有修改过 1 for modified, 0 for not modified  # noqa: E501

        :return: The modified of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._modified

    @modified.setter
    def modified(self, modified):
        """Sets the modified of this ScenarioInfo.

        1表示修改过，0表示没有修改过 1 for modified, 0 for not modified  # noqa: E501

        :param modified: The modified of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._modified = modified

    @property
    def auto_calculate(self):
        """Gets the auto_calculate of this ScenarioInfo.  # noqa: E501

        1表示自动计算，0表示非自动计算 1 for auto calculate, 0 for not auto calculate  # noqa: E501

        :return: The auto_calculate of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._auto_calculate

    @auto_calculate.setter
    def auto_calculate(self, auto_calculate):
        """Sets the auto_calculate of this ScenarioInfo.

        1表示自动计算，0表示非自动计算 1 for auto calculate, 0 for not auto calculate  # noqa: E501

        :param auto_calculate: The auto_calculate of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._auto_calculate = auto_calculate

    @property
    def create_time(self):
        """Gets the create_time of this ScenarioInfo.  # noqa: E501

        方案创建时刻 scenario create time  # noqa: E501

        :return: The create_time of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this ScenarioInfo.

        方案创建时刻 scenario create time  # noqa: E501

        :param create_time: The create_time of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._create_time = create_time

    @property
    def end_time(self):
        """Gets the end_time of this ScenarioInfo.  # noqa: E501

        模型结束时刻 model end time  # noqa: E501

        :return: The end_time of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ScenarioInfo.

        模型结束时刻 model end time  # noqa: E501

        :param end_time: The end_time of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._end_time = end_time

    @property
    def start_time(self):
        """Gets the start_time of this ScenarioInfo.  # noqa: E501

        模型开始时刻 model start time  # noqa: E501

        :return: The start_time of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ScenarioInfo.

        模型开始时刻 model start time  # noqa: E501

        :param start_time: The start_time of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._start_time = start_time

    @property
    def current_time(self):
        """Gets the current_time of this ScenarioInfo.  # noqa: E501

        模型预报时刻 model current time or forecast time  # noqa: E501

        :return: The current_time of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._current_time

    @current_time.setter
    def current_time(self, current_time):
        """Sets the current_time of this ScenarioInfo.

        模型预报时刻 model current time or forecast time  # noqa: E501

        :param current_time: The current_time of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._current_time = current_time

    @property
    def project_file(self):
        """Gets the project_file of this ScenarioInfo.  # noqa: E501

        模型文件名称 model file name  # noqa: E501

        :return: The project_file of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._project_file

    @project_file.setter
    def project_file(self, project_file):
        """Sets the project_file of this ScenarioInfo.

        模型文件名称 model file name  # noqa: E501

        :param project_file: The project_file of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._project_file = project_file

    @property
    def relative_folder(self):
        """Gets the relative_folder of this ScenarioInfo.  # noqa: E501

        方案文件夹相对于WorkFolder的路径 scenario's relative path to WorkFolder  # noqa: E501

        :return: The relative_folder of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._relative_folder

    @relative_folder.setter
    def relative_folder(self, relative_folder):
        """Sets the relative_folder of this ScenarioInfo.

        方案文件夹相对于WorkFolder的路径 scenario's relative path to WorkFolder  # noqa: E501

        :param relative_folder: The relative_folder of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._relative_folder = relative_folder

    @property
    def enabled(self):
        """Gets the enabled of this ScenarioInfo.  # noqa: E501

        1表示启用，0表示不启用 1 for enabled, 0 for disabled  # noqa: E501

        :return: The enabled of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this ScenarioInfo.

        1表示启用，0表示不启用 1 for enabled, 0 for disabled  # noqa: E501

        :param enabled: The enabled of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._enabled = enabled

    @property
    def read_only(self):
        """Gets the read_only of this ScenarioInfo.  # noqa: E501

        1表示只读，0表示可读写 1 for readonly, 0 for not readonly  # noqa: E501

        :return: The read_only of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this ScenarioInfo.

        1表示只读，0表示可读写 1 for readonly, 0 for not readonly  # noqa: E501

        :param read_only: The read_only of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._read_only = read_only

    @property
    def inherited_scenario(self):
        """Gets the inherited_scenario of this ScenarioInfo.  # noqa: E501

        父方案ID parent scenario Id  # noqa: E501

        :return: The inherited_scenario of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._inherited_scenario

    @inherited_scenario.setter
    def inherited_scenario(self, inherited_scenario):
        """Sets the inherited_scenario of this ScenarioInfo.

        父方案ID parent scenario Id  # noqa: E501

        :param inherited_scenario: The inherited_scenario of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._inherited_scenario = inherited_scenario

    @property
    def id(self):
        """Gets the id of this ScenarioInfo.  # noqa: E501

        方案ID scenario Id  # noqa: E501

        :return: The id of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ScenarioInfo.

        方案ID scenario Id  # noqa: E501

        :param id: The id of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def scenario_code(self):
        """Gets the scenario_code of this ScenarioInfo.  # noqa: E501

        方案代码 scenario code  # noqa: E501

        :return: The scenario_code of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._scenario_code

    @scenario_code.setter
    def scenario_code(self, scenario_code):
        """Sets the scenario_code of this ScenarioInfo.

        方案代码 scenario code  # noqa: E501

        :param scenario_code: The scenario_code of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._scenario_code = scenario_code

    @property
    def scenario_name(self):
        """Gets the scenario_name of this ScenarioInfo.  # noqa: E501

        方案名称 scenario name  # noqa: E501

        :return: The scenario_name of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._scenario_name

    @scenario_name.setter
    def scenario_name(self, scenario_name):
        """Sets the scenario_name of this ScenarioInfo.

        方案名称 scenario name  # noqa: E501

        :param scenario_name: The scenario_name of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._scenario_name = scenario_name

    @property
    def model_type(self):
        """Gets the model_type of this ScenarioInfo.  # noqa: E501

        模型类型，包括但不限于 model type, including but not limited to:  0-MIKE11Model(MIKE 11 model),  2-MIKE21Model(MIKE 21 model),  3-MIKE21FMModel(MIKE 21FM model),  4-MIKE3FMModel(MIKE 3FM model),  5-MIKEFloodModel(MIKE Flood model),  7-MIKEUrbanCSModel(MIKE Urban CS model),  8-MIKEUrbanWDModel(MIKE Urban WD model),  9-HydroBasinModel(MIKE HYDRO Basin model),  12-FeflowModel(MIKE Feflow model),  13-WestModel(West model),  20-HammerModel(Hammer model of WD),  21-MIKEPlusFloodModel(MIKE Plus Flood model),  22-MIKEPlusWDModel(MIKE Plus WD model),  99-Unknown(Unknown),  # noqa: E501

        :return: The model_type of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this ScenarioInfo.

        模型类型，包括但不限于 model type, including but not limited to:  0-MIKE11Model(MIKE 11 model),  2-MIKE21Model(MIKE 21 model),  3-MIKE21FMModel(MIKE 21FM model),  4-MIKE3FMModel(MIKE 3FM model),  5-MIKEFloodModel(MIKE Flood model),  7-MIKEUrbanCSModel(MIKE Urban CS model),  8-MIKEUrbanWDModel(MIKE Urban WD model),  9-HydroBasinModel(MIKE HYDRO Basin model),  12-FeflowModel(MIKE Feflow model),  13-WestModel(West model),  20-HammerModel(Hammer model of WD),  21-MIKEPlusFloodModel(MIKE Plus Flood model),  22-MIKEPlusWDModel(MIKE Plus WD model),  99-Unknown(Unknown),  # noqa: E501

        :param model_type: The model_type of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._model_type = model_type

    @property
    def model_sub_type(self):
        """Gets the model_sub_type of this ScenarioInfo.  # noqa: E501

        方案子类型，包括但不限于 scenario subtype, including but not limited to:  0-ManualSchedule(Manual schedule),  2-OptimizeSchedule(Optimization schedule),  5-EmerResponse(Emergency response),  6-Forecast(Forecast and warning),  8-Scenario(Scenario simulation),  9-Incident(Accident),  12-WQEvaluation(Water quality evaluation),  14-Planning(Planning),  15-OilSpill(Oil spill accident),  19-PumpShutdown(Pump shut down scenario),  20-PipeBurst(Pipe burst scenario),  99-Unknown(Unknown),  # noqa: E501

        :return: The model_sub_type of this ScenarioInfo.  # noqa: E501
        :rtype: str
        """
        return self._model_sub_type

    @model_sub_type.setter
    def model_sub_type(self, model_sub_type):
        """Sets the model_sub_type of this ScenarioInfo.

        方案子类型，包括但不限于 scenario subtype, including but not limited to:  0-ManualSchedule(Manual schedule),  2-OptimizeSchedule(Optimization schedule),  5-EmerResponse(Emergency response),  6-Forecast(Forecast and warning),  8-Scenario(Scenario simulation),  9-Incident(Accident),  12-WQEvaluation(Water quality evaluation),  14-Planning(Planning),  15-OilSpill(Oil spill accident),  19-PumpShutdown(Pump shut down scenario),  20-PipeBurst(Pipe burst scenario),  99-Unknown(Unknown),  # noqa: E501

        :param model_sub_type: The model_sub_type of this ScenarioInfo.  # noqa: E501
        :type: str
        """

        self._model_sub_type = model_sub_type

    @property
    def template(self):
        """Gets the template of this ScenarioInfo.  # noqa: E501

        1表示模板方案，0表示非模板方案 1 or 0, indicating if the scenario is a template or not  # noqa: E501

        :return: The template of this ScenarioInfo.  # noqa: E501
        :rtype: int
        """
        return self._template

    @template.setter
    def template(self, template):
        """Sets the template of this ScenarioInfo.

        1表示模板方案，0表示非模板方案 1 or 0, indicating if the scenario is a template or not  # noqa: E501

        :param template: The template of this ScenarioInfo.  # noqa: E501
        :type: int
        """

        self._template = template

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScenarioInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScenarioInfo):
            return True

        return self.to_dict() != other.to_dict()
